@@ -1,5 +1,5 @@
-/*  MikMod example player
-	(c) 1999 Miodrag Vallat and others - see file AUTHORS for
+/*  MikMod module player
+	(c) 1998 - 2000 Miodrag Vallat and others - see file AUTHORS for
 	complete list.
 
 	This program is free software; you can redistribute it and/or modify
@@ -14,13 +14,13 @@
  
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+	02111-1307, USA.
 */
 
 /*==============================================================================
 
-  $Id: mmenu.h,v 1.1.1.1 2003/09/19 13:16:01 raph Exp $
+  $Id: mmenu.h,v 1.1.1.1 2004/01/16 02:07:38 raph Exp $
 
   Menu functions
 
@@ -34,7 +34,8 @@
 /* text metacharacters:
    '&x': highlight 'x'
    '&&' -> '&'
-   '-' : separator, if first character
+   '%%' -> '%'
+   '%-' : separator, if at start of text
    '%c': toggle menu
          data: menu active yes|no
    '%o...|opt0|opt1|...': option menu
@@ -43,9 +44,9 @@
          data: current value
    '%s...|label|maxlength|length of inserted text': string input
          data: current value
-   '>': submenu, if last character
+   '%>': submenu, if at end of text
          data: struct *MMENU, the sub menu
-   else: normal menu ( '%%' -> '%')
+   else: normal menu
          data: unused
 */
 typedef struct {
@@ -54,22 +55,25 @@ typedef struct {
 	char *help;
 } MENTRY;
 
-typedef struct MMENU{
-	int cur;        /* selected entry */
-	int first;      /* first line of menu which is displayed */
-	int count;      /* number of menu entries */
-	BOOL key_left;  /* can menu be closed with KEY_LEFT */
+typedef struct MMENU {
+	int cur;				/* selected entry */
+	int first;				/* first line of menu which is displayed */
+	int count;				/* number of menu entries, -1 -> count is determined */
+							/* by first NULL entry in entries[].text */
+	BOOL key_left;			/* can menu be closed with KEY_LEFT or KEY_ESC? */
 	MENTRY *entries;
-	void (*handle_select) (struct MMENU *menu); /* called on menu selection */
-	MWINDOW *win;   /* the window for this menu */
+	void (*handle_select) (struct MMENU *menu);	/* called on menu selection */
+	MWINDOW *win;			/* the window for this menu */
 
-	void *data;     /* not used by menu functions */
-	int id;         /* not used by menu functions */
+	void *data;				/* not used by menu functions */
+	int id;					/* not used by menu functions */
 } MMENU;
 
-typedef void (*MenuSelectFunc)(MMENU*,int);
+typedef void (*MenuSelectFunc) (MMENU *menu);
 
-void menu_open(MMENU*,int,int);
-void menu_close(MMENU*);
+void menu_open(MMENU * menu, int x, int y);
+void menu_close(MMENU * menu);
 
-#endif  /* MMENU_H */
+#endif /* MMENU_H */
+
+/* ex:set ts=4: */
