@@ -1,5 +1,5 @@
 /*  MikMod module player
-	(c) 1998 - 2000 Miodrag Vallat and others - see file AUTHORS for
+	(c) 1998 - 2014 Miodrag Vallat and others - see file AUTHORS for
 	complete list.
 
 	This program is free software; you can redistribute it and/or modify
@@ -20,8 +20,6 @@
 
 /*==============================================================================
 
-  $Id: mutilities.h,v 1.1.1.1 2004/01/16 02:07:34 raph Exp $
-
   Some utility functions
 
 ==============================================================================*/
@@ -29,33 +27,55 @@
 #ifndef MUTILITIES_H
 #define MUTILITIES_H
 
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
-#elif defined(__OS2__)||defined(__EMX__)
+#endif
+
+#if defined(__OS2__)||defined(__EMX__)
 #include <os2.h>
+#ifndef HAVE_CONFIG_H
+#define RETSIGTYPE void
+#endif
+#endif
+
+#if defined(__MORPHOS__) || defined(__AROS__) || defined(AMIGAOS)	|| \
+    defined(__amigaos__) || defined(__amigados__)			|| \
+    defined(AMIGA) || defined(_AMIGA) || defined(__AMIGA__)
+#include <exec/types.h>
+#define _mikmod_amiga 1
 #endif
 
 #include <mikmod.h>	/* for BOOL */
 
 /*========== Constants */
 
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
+
 #ifndef PATH_MAX
-#ifdef _POSIX_PATH_MAX
-#define PATH_MAX _POSIX_PATH_MAX
-#elif defined(_MAX_PATH)
+#if defined(MAXPATHLEN) /* <sys/param.h> */
+#define PATH_MAX MAXPATHLEN
+#elif defined(_WIN32) && defined(_MAX_PATH)
 #define PATH_MAX _MAX_PATH
+#elif defined(_WIN32) && defined(MAX_PATH)
+#define PATH_MAX MAX_PATH
+#elif defined(__OS2__) && defined(CCHMAXPATH)
+#define PATH_MAX CCHMAXPATH
 #else
 #define PATH_MAX 256
 #endif
-#endif
+#endif /* PATH_MAX */
+
+#include <string.h>
 
 #define PATH_SEP '/'
 #define PATH_SEP_STR "/"
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)
 
 #define PATH_SEP_SYS '\\'
 #define PATH_SEP_SYS_STR "\\"
@@ -73,6 +93,24 @@ char *path_conv_sys2(const char *file);
 
 #endif
 
+#ifdef _mikmod_amiga
+#define IS_PATH_SEP(c) ((c) == PATH_SEP || (c) == ':')
+static inline char *FIND_FIRST_DIRSEP(const char *_the_path) {
+    char *p = strchr(_the_path, ':');
+    if (p != NULL) return p;
+    return strchr(_the_path, PATH_SEP);
+}
+static inline char *FIND_LAST_DIRSEP (const char *_the_path) {
+    char *p = strrchr(_the_path, PATH_SEP);
+    if (p != NULL) return p;
+    return strchr(_the_path, ':');
+}
+#else
+#define IS_PATH_SEP(c) ((c) == PATH_SEP)
+#define FIND_FIRST_DIRSEP(p) strchr((p), PATH_SEP)
+#define FIND_LAST_DIRSEP(p) strrchr((p), PATH_SEP)
+#endif
+
 /*========== Types */
 
 /* pointer-sized signed int (ssize_t/intptr_t) : */
@@ -96,7 +134,7 @@ extern char storage[STORAGELEN+2];
 
 #define BTST(v, m) ((v) & (m) ? 1 : 0)
 
-#ifdef WIN32
+#ifdef _WIN32
 #define stat              _stat
 #ifndef S_ISDIR
 #define S_ISDIR(st_mode)  ((st_mode & _S_IFDIR) == _S_IFDIR)
@@ -109,22 +147,19 @@ extern char storage[STORAGELEN+2];
 #endif
 #endif
 
-#if defined(__EMX__)||defined(WIN32)
+#if defined(__EMX__)||defined(_WIN32)
 #undef S_ISBLK /* MinGW sys/stat.h does define S_ISBLK */
 #define S_ISBLK(st_mode)  0
 #endif
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)
 #undef S_ISLNK /* djgpp-v2.04 does define S_ISLNK (and has lstat, too..) */
 #define lstat             stat
 #define S_ISSOCK(st_mode) 0
 #define S_ISLNK(st_mode)  0
 #endif
 
-#if defined(__OS2__)||defined(__EMX__)||(defined(WIN32)&&!defined(__MINGW32__))
-
-/* FIXME , untested under OS2 */
-
+#if defined(_WIN32)&&!defined(__MINGW32__)&&!defined(__WATCOMC__)
 typedef struct dirent {
 	char name[PATH_MAX+1];
 	unsigned long* handle;
@@ -135,8 +170,7 @@ typedef struct dirent {
 DIR* opendir (const char* dirName);
 struct dirent *readdir (DIR* dir);
 int closedir (DIR* dir);
-
-#endif
+#endif /* dirent _WIN32 */
 
 /* allocate memory for a formated string and do a sprintf */
 char *str_sprintf2(const char *fmt, const char *arg1, const char *arg2);
@@ -149,7 +183,7 @@ int get_tmp_file (const char *tmpl, char **name_used);
 
 /* allocate and return a name for a temporary file
    (under UNIX not used because of tempnam race condition) */
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)||defined(_mikmod_amiga)
 char *get_tmp_name(void);
 #endif
 
@@ -164,12 +198,12 @@ char *get_cfg_name(const char *name);
 /* Return precise time in milliseconds */
 unsigned long Time1000(void);
 
-#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(WIN32)
+#if defined(__OS2__)||defined(__EMX__)||defined(__DJGPP__)||defined(_WIN32)||defined(_mikmod_amiga)
 #define filecmp strcasecmp
 #else
 #define filecmp strcmp
 #endif
-#if defined(__OS2__)||defined(__EMX__)||(defined(WIN32)&&!defined(__MINGW32__))
+#if defined(__OS2__)||defined(__EMX__)||(defined(_WIN32)&&!defined(__MINGW32__))
 #define strcasecmp(s,t) stricmp(s,t)
 #endif
 
